import request from '@/utils/request'
// 会议活动-列表 zxConference:conference:list
export function getMeetListFn(data) {
  return request({
    'url': '/zxConference/conference/list',
    'method': 'get',
	'data':data
  })
}
// 会议活动不分页zxConference:conference:listNoPage
export function getMeetListNopageFn(data) {
  return request({
    'url': '/zxConference/conference/listNoPage',
    'method': 'get',
	'data':data
  })
}
// 会议活动-详情 zxConference:conference:query
export function getMeetDetaiFn(data) {
  return request({
    'url': '/zxConference/conference/info',
    'method': 'post',
	'data':data
  })
}
// 会议活动-新增 zxConference:conference:query
export function getMeetAddFn(data) {
  return request({
    'url': '/zxConference/conference',
    'method': 'post',
	'data':data
  })
}
// 会议活动-修改 zxConference:conference:edit
export function getMeetEditFn(data) {
  return request({
    'url': '/zxConference/conference/put',
    'method': 'post',
	'data':data
  })
}
// 会议活动-删除 zxConference:conference:remove
export function getMeetDelFn(data) {
  return request({
    'url': '/zxConference/conference/delete/'+data,
    'method': 'get',
  })
}
//会议活动人员-详情zxConference:conference:getUserInfo
export function getMeetPeoListFn(data) {
  return request({
    'url': '/zxConference/conference/getUserInfo',
    'method': 'post',
	'data':data
  })
}
//委员信息-列表下拉树 人员信息
export function getInfotreeSelectFn(data) {
  return request({
    'url': '/member/info/treeSelect',
    'method': 'get',
	'data':data
  })
}
// 政协发言-列表 zx:speak:list
export function getSpeakListFn(data) {
  return request({
    'url': '/zx/speak/list',
    'method': 'get',
	'data':data
  })
}
// 政协发言-新增 zx:speak:add
export function getSpeakAddFn(data) {
  return request({
    'url': '/zx/speak',
    'method': 'post',
	'data':data
  })
}
// 政协发言-修改 zx:speak:edit
export function getSpeakEditFn(data) {
  return request({
    'url': '/zx/speak/put',
    'method': 'post',
	'data':data
  })
}
// 政协发言-删除 zx:speak:edit
export function getSpeakDelFn(data) {
  return request({
    'url': '/zx/speak/delete/'+data,
    'method': 'get',
  })
}
// 政协发言-详情 zx:speak:query
export function getSpeakDetailFn(data) {
  return request({
    'url': '/zx/speak/'+data,
    'method': 'get',
  })
}
// 会议活动-修改会议答复信息 zxConference:conference:updateReply
export function getupdateReplyFn(data) {
  return request({
    'url': '/zxConference/conference/updateReply',
    'method': 'post',
	'data':data
  })
}
//会议活动-签到zxConference:conference:signIn
export function getsignInFn(data) {
  return request({
    'url': '/zxConference/conference/signIn',
    'method': 'post',
	'data':data
  })
}


// 政协活动-列表 zxActivity:activity:list
export function getzxActivityListFn(data) {
  return request({
    'url': '/zxActivity/activity/list',
    'method': 'get',
	'data':data
  })
}
// 政协活动-新增 zxActivity:activity:add
export function getzxActivityAddFn(data) {
  return request({
    'url': '/zxActivity/activity',
    'method': 'post',
	'data':data
  })
}
// 政协活动-修改 zxActivity:activity:edit
export function getzxActivityEditFn(data) {
  return request({
    'url': '/zxActivity/activity/put',
    'method': 'post',
	'data':data
  })
}
// 政协活动-删除 zxActivity:activity:remove
export function getzxActivityDelFn(data) {
  return request({
    'url': '/zxActivity/activity/delete/'+data,
    'method': 'get',
  })
}
// 政协活动-详情 zxActivity:activity:query
export function getzxActivityDetailFn(data) {
  return request({
    'url': '/zxActivity/activity/info',
    'method': 'post',
	'data':data
  })
}
// 政协活动-修改活动答复信息 zxActivity:activity:updateReply
export function getzxActivityReplyFn(data) {
  return request({
    'url': '/zxActivity/activity/updateReply',
    'method': 'post',
	'data':data
  })
}
// 政协活动人员-详情zxActivity:activity:getUserInfo
export function getzxActivityPeoFn(data) {
  return request({
    'url': '/zxActivity/activity/getUserInfo',
    'method': 'post',
	'data':data
  })
}
//政协活动-修改请假审批zxActivity:activity:updateApproval
export function getzxActivitypsFn(data) {
  return request({
    'url': '/zxActivity/activity/updateApproval',
    'method': 'post',
	'data':data
  })
}
//会议活动-修改会议答复信息zxConference:conference:updateApproval
export function getzxConferencepsFn(data) {
  return request({
    'url': '/zxConference/conference/updateApproval',
    'method': 'post',
	'data':data
  })
}

//招商引资-列表zx:investment:list
export function getinvestmentListFn(data) {
  return request({
    'url': '/zx/investment/list',
    'method': 'get',
	'data':data
  })
}
//招商引资-新增zx:investment:add
export function getinvestmentAddFn(data) {
  return request({
    'url': '/zx/investment',
    'method': 'post',
	'data':data
  })
}
//招商引资-修改zx:investment:edit
export function getinvestmentEditFn(data) {
  return request({
    'url': '/zx/investment/put',
    'method': 'post',
	'data':data
  })
}
//招商引资-删除zx:investment:remove
export function getinvestmentDelFn(data) {
  return request({
    'url': '/zx/investment/delete/'+data,
    'method': 'get',
  })
}
//招商引资-详情zx:investment:query
export function getinvestmentDetailFn(data) {
  return request({
    'url': '/zx/investment/'+data,
    'method': 'get',
  })
}
//招商引资-审核/签约按钮zx:investment:examine
export function getinvestmentshlFn(data) {
  return request({
    'url': '/zx/investment/examine',
    'method': 'post',
	'data':data
  })
}

// 会议通知-列表 zxConference:conference:list
// export function getMeetListFn(data) {
//   return request({
//     'url': '/zxConference/conference/list',
//     'method': 'get',
// 	'data':data
//   })
// }